==> csx600_m512_le_base_RHE4_64-2.24.tgz: opt/clearspeed/csx600_m512_le/include/csdft.h <==
/*
 *
 *     Copyright (c) 2006, ClearSpeed Technology plc. All rights reserved.
 *
 * This material is provided "as is", with absolutely no warranty expressed or
 * implied. Any use is at your own risk. Permission to use or copy this software
 * for any purpose is hereby granted without fee, provided the above notices are
 * retained on all copies. Permission to modify the code and to distribute
 * modified code is granted, provided the above notices are retained, and a
 * notice that the code was modified is included with the above copyright notice.
 *
 */

#ifndef __CSDFT_H
#define __CSDFT_H

#define CSDFT_MAX_NUM_COMPUTE_FUNCS 5

struct CSDftPlanEngine
{
    unsigned int   compute_func[CSDFT_MAX_NUM_COMPUTE_FUNCS];
    unsigned int   read_io_func;
    unsigned int   write_io_func;
    unsigned int   read_io_setup_func;
    unsigned int   write_io_setup_func;
    unsigned int   user_func_defunct; // Run after the compute func - should this be a
                              // compute func?
    unsigned int   num_nodes;
    unsigned short unused;
    unsigned short num_buffers;
    unsigned short num_read_addr_masks;
    unsigned short num_write_addr_masks;
    unsigned int   buffer_size;
    unsigned short func_index;
    unsigned short size;
    unsigned int   complex_buf_src_offset;
    unsigned int   complex_buf_dst_offset;
    unsigned int   flags;
    unsigned int   stride;
    double         scale_forward;
    double         scale_backward;
};


/* Do not write to these values directly
 instead createPlan should be used
*/


struct CSDftPlanObj  {
    unsigned short   size_per_pe_sample;
    unsigned short unused_1;
    unsigned short num_pes_per_fft;
    unsigned short ffts_across_array;
    unsigned int   sample_size_per_fft;
    unsigned short num_engines;
    unsigned short unused_2;
    unsigned int   flags;
    double         scale_forward_defunct;
    double         scale_backward_defunct;
    void          *user_data;
    struct CSDftPlanEngine engines[3];
    struct CSDftPlanObj  *next;
    unsigned int   repeat_fft;
    unsigned int   repeat_in_stride;
    unsigned int   repeat_out_stride;
};


struct CSDftExecuteInfoPolyObj {
    unsigned int   result_offset;
};

typedef      struct CSDftPlanObj                 * CSDftPlan;
typedef      struct CSDftUserPlanObj             * CSDftUserPlan;
typedef poly struct CSDftExecuteInfoPolyObj      * CSDftExecuteInfoPoly;


struct CSDftMemoryDescriptorObj
{
    void *       data_pointer ;
    void *       data_pointer_imag ;
    unsigned int null_memory_descriptor ;
    unsigned int split_arrays ;
    unsigned int size_in_bytes ;
    unsigned int number_of_buffers ;

    unsigned int board_instance ;
    unsigned int processor_instance ;
    unsigned int start_buffer ;
    unsigned int end_buffer ;
    struct CSDftMemoryDescriptorObj * next;
} ;

typedef struct CSDftMemoryDescriptorObj *CSDftMemoryDescriptor;


//============================================================================//
// defines, enums, struct and typedef declarations for CSDftPlan              //
//============================================================================//
#define CSDFT_DIRECTION                 0                       // 1 bit
#define CSDFT_ORDER                     1                       // 1 bit
#define CSDFT_SRC_PRECISION             2                       // 2 bits
#define CSDFT_SRC_TYPE                  4                       // 1 bits
#define CSDFT_DST_PRECISION             5                       // 2 bit
#define CSDFT_DST_TYPE                  7                       // 1 bit

#define CSDFT_SRC_FORMAT                30                      // 1 bit
#define CSDFT_DST_FORMAT                31                      // 1 bit

#define CSDFT_DIRECTION_MASK            0x1                     // bit 0
#define CSDFT_ORDER_MASK                0x2                     // bit 1
#define CSDFT_SRC_PRECISION_MASK        0xC                     // bit 2&3
#define CSDFT_SRC_TYPE_MASK             0x10                    // bit 4
#define CSDFT_DST_PRECISION_MASK        0x60                    // bit 5&6
#define CSDFT_DST_TYPE_MASK             0x80                    // bit 7

#define CSDFT_CONVOLVE_TRANSFORM_MASK   0x20000000              /* bit 29   */
#define CSDFT_SRC_FORMAT_MASK           0x40000000              // bit 30
#define CSDFT_DST_FORMAT_MASK           0x80000000UL            // bit 31

#define CSDFT_FORWARD                   (0 << CSDFT_DIRECTION)      // Default is FORWARD (0)
#define CSDFT_BACKWARD                  (1 << CSDFT_DIRECTION)      //                    (1)

#define CSDFT_NATURAL_ORDER             (0 << CSDFT_ORDER)          // Defaul is NATURAL
#define CSDFT_OPTIMAL_ORDER             (1 << CSDFT_ORDER)
//#define CSDFT_BIT_REVERSED_ORDER      (2 << CSDFT_ORDER)

#define CSDFT_SRC_BYTE                  (0 << CSDFT_SRC_PRECISION)  // Default is SINGLE
#define CSDFT_SRC_SHORT                 (1 << CSDFT_SRC_PRECISION)
#define CSDFT_SRC_SINGLE                (2 << CSDFT_SRC_PRECISION)
#define CSDFT_SRC_DOUBLE                (3 << CSDFT_SRC_PRECISION)

#define CSDFT_SRC_REAL                  (0 << CSDFT_SRC_TYPE)       // Default is COMPLEX
#define CSDFT_SRC_COMPLEX               (1 << CSDFT_SRC_TYPE)

#define CSDFT_DST_BYTE                  (0 << CSDFT_DST_PRECISION)  // Default is SINGLE
#define CSDFT_DST_SHORT                 (1 << CSDFT_DST_PRECISION)
#define CSDFT_DST_SINGLE                (2 << CSDFT_DST_PRECISION)
#define CSDFT_DST_DOUBLE                (3 << CSDFT_DST_PRECISION)

#define CSDFT_DST_REAL                  (0 << CSDFT_DST_TYPE)       // Default is COMPLEX
#define CSDFT_DST_COMPLEX               (1 << CSDFT_DST_TYPE)

#define CSDFT_SRC_INTERLEAVED           (0 << CSDFT_SRC_FORMAT)     // Default is INTERLEAVED
#define CSDFT_SRC_SPLIT_ARRAY           (1 << CSDFT_SRC_FORMAT)
#define CSDFT_DST_INTERLEAVED           (0 << CSDFT_DST_FORMAT)     // Default is INTERLEAVED
#define CSDFT_DST_SPLIT_ARRAY           (1 << CSDFT_DST_FORMAT)

// Combined source and destination
#define CSDFT_BYTE                      (CSDFT_SRC_BYTE|CSDFT_DST_BYTE)
#define CSDFT_SHORT                     (CSDFT_SRC_SHORT|CSDFT_DST_SHORT)
#define CSDFT_SINGLE                    (CSDFT_SRC_SINGLE|CSDFT_DST_SINGLE)
#define CSDFT_DOUBLE                    (CSDFT_SRC_DOUBLE|CSDFT_DST_DOUBLE)
#define CSDFT_REAL                      (CSDFT_SRC_REAL|CSDFT_DST_REAL)
#define CSDFT_COMPLEX                   (CSDFT_SRC_COMPLEX|CSDFT_DST_COMPLEX)
#define CSDFT_INTERLEAVED               (CSDFT_SRC_INTERLEAVED|CSDFT_DST_INTERLEAVED)
#define CSDFT_SPLIT_ARRAY               (CSDFT_SRC_SPLIT_ARRAY|CSDFT_DST_SPLIT_ARRAY)
#define CSDFT_TRANSFORM_KERNEL           CSDFT_CONVOLVE_TRANSFORM_MASK


typedef unsigned int CSDftFlags;


//============================================================================//
// enums and function prototypes for CSDft status routines                    //
//============================================================================//


enum _CSDftStatusTypes
{
    CSDFT_NO_ERROR,
    CSDFT_RUNNING,
    CSDFT_FINISHED,
    CSDFT_BOARD_ERROR,
    CSDFT_INVALID_BOARD,
    CSDFT_INVALID_PROCESSOR,
    CSDFT_MEMORY_ALLOCATION_ERROR,
    CSDFT_INVALID_MEMORY_DESCRIPTOR,
    CSDFT_INVALID_PLAN,
    CSDFT_INVALID_USER_FUNCTION,
    CSDFT_INVALID_SYMBOL,
    CSDFT_INVALID_SIZE,
    CSDFT_INVALID_FLAG,
    CSDFT_INVALID_PARAMETER
} ;

typedef enum _CSDftStatusTypes CSDftStatus ;

CSDftStatus CSDFT_get_status                () ;


//============================================================================//
// Function prototypes for CSDftPlan creation and execution routines          //
//============================================================================//


CSDftPlan CSDFT_create_plan_1d               (CSDftFlags    flags,
                                           unsigned int  size,
                                           unsigned int  number_of_ffts,
                                           double        scale);

CSDftPlan CSDFT_create_plan_2d               (CSDftFlags    flags,
                                           unsigned int  size_x,
                                           unsigned int  size_y,
                                           unsigned int  number_of_ffts,
                                           double        scale);
CSDftPlan CSDFT_create_plan_3d               (CSDftFlags    flags,
                                           unsigned int  size_x,
                                           unsigned int  size_y,
                                           unsigned int  size_z,
                                           unsigned int  number_of_ffts,
                                           double        scale);

CSDftPlan CSDFT_create_plan_1d_strided ( CSDftFlags   flags,
                                         unsigned int size,
                                         unsigned int num_ffts,
                                         double       scale,
                                         unsigned int fft_stride,
                                         unsigned int node_stride);

CSDftPlan CSDFT_create_convolution_plan_1d ( CSDftFlags   flags,
                                             unsigned int size,
                                             unsigned int number_of_ffts,
                                             double       scale
                                             ) ;

CSDftPlan CSDFT_create_convolution_plan_2d ( CSDftFlags   flags,
                                             unsigned int x_size,
                                             unsigned int y_size,
                                             unsigned int number_of_ffts,
                                             double       scale
                                             ) ;

CSDftStatus CSDFT_execute_convolution( const CSDftPlan       plan,
                                       CSDftMemoryDescriptor kernel,
                                       CSDftMemoryDescriptor source,
                                       CSDftMemoryDescriptor destination ) ;

CSDftStatus CSDFT_execute_dft      (const CSDftPlan handle,
                                    CSDftMemoryDescriptor src,
                                    CSDftMemoryDescriptor dst);

CSDftStatus CSDFT_free_plan                 (CSDftPlan plan);

CSDftMemoryDescriptor CSDFT_board_to_memory_descriptor
                                       ( void *       source_data,
                                         unsigned int size_in_bytes) ;

void *CSDFT_memory_descriptor_to_board( CSDftMemoryDescriptor handle ) ;

CSDftStatus           CSDFT_free        ( CSDftMemoryDescriptor handle ) ;

#define CSDFT_USER_SEM                   0x25

#endif

==> csx600_m512_le_base_RHE4_64-2.50.tgz: opt/clearspeed/csx600_m512_le/include/csdft.h <==
/*
 *
 *     Copyright (c) 2006, ClearSpeed Technology plc. All rights reserved.
 *
 * This material is provided "as is", with absolutely no warranty expressed or
 * implied. Any use is at your own risk. Permission to use or copy this software
 * for any purpose is hereby granted without fee, provided the above notices are
 * retained on all copies. Permission to modify the code and to distribute
 * modified code is granted, provided the above notices are retained, and a
 * notice that the code was modified is included with the above copyright notice.
 *
 */

#ifndef __CSDFT_H
#define __CSDFT_H

#define CSDFT_MAX_NUM_COMPUTE_FUNCS 5

struct CSDftPlanEngine
{
    unsigned int   compute_func[CSDFT_MAX_NUM_COMPUTE_FUNCS];
    unsigned int   read_io_func;
    unsigned int   write_io_func;
    unsigned int   read_io_setup_func;
    unsigned int   write_io_setup_func;
    unsigned int   user_func_defunct; // Run after the compute func - should this be a
                              // compute func?
    unsigned int   num_ffts;
    unsigned short unused;
    unsigned short num_buffers;
    unsigned short num_read_addr_masks;
    unsigned short num_write_addr_masks;
    unsigned int   buffer_size;
    unsigned short func_index;
    unsigned short num_nodes_per_fft;
    unsigned int   complex_buf_src_offset;
    unsigned int   complex_buf_dst_offset;
    unsigned int   flags;
    unsigned int   stride;
    unsigned int   func_index_for_num_ffts;
    double         scale_forward;
    double         scale_backward;
    unsigned short num_pes_per_fft;
    unsigned short ffts_across_array;
    unsigned int   sample_size_per_fft;
};


/* Do not write to these values directly
 instead createPlan should be used
*/


struct CSDftPlanObj  {
    unsigned short   size_per_pe_sample;
    unsigned short unused_1;
    unsigned short _old_num_pes_per_fft;
    unsigned short _old_ffts_across_array;
    unsigned int   _old_sample_size_per_fft;
    unsigned short num_engines;
    unsigned short unused_2;
    unsigned int   flags;
    double         scale_forward_defunct;
    double         scale_backward_defunct;
    void          *user_data;
    struct CSDftPlanEngine engines[3];
    struct CSDftPlanObj  *next;
    unsigned int   repeat_fft;
    unsigned int   repeat_in_stride;
    unsigned int   repeat_out_stride;
};


struct CSDftExecuteInfoPolyObj {
    unsigned int   result_offset;
};

typedef      struct CSDftPlanObj                 * CSDftPlan;
typedef      struct CSDftUserPlanObj             * CSDftUserPlan;
typedef poly struct CSDftExecuteInfoPolyObj      * CSDftExecuteInfoPoly;


struct CSDftMemoryDescriptorObj
{
    void *       data_pointer ;
    void *       data_pointer_imag ;
    unsigned int null_memory_descriptor ;
    unsigned int split_arrays ;
    unsigned int size_in_bytes ;
    unsigned int number_of_buffers ;

    unsigned int board_instance ;
    unsigned int processor_instance ;
    unsigned int start_buffer ;
    unsigned int end_buffer ;
    struct CSDftMemoryDescriptorObj * next;
} ;

typedef struct CSDftMemoryDescriptorObj *CSDftMemoryDescriptor;


//============================================================================//
// defines, enums, struct and typedef declarations for CSDftPlan              //
//============================================================================//
#define CSDFT_DIRECTION                 0                       // 1 bit
#define CSDFT_ORDER                     1                       // 1 bit
#define CSDFT_SRC_PRECISION             2                       // 2 bits
#define CSDFT_SRC_TYPE                  4                       // 1 bits
#define CSDFT_DST_PRECISION             5                       // 2 bit
#define CSDFT_DST_TYPE                  7                       // 1 bit

#define CSDFT_SRC_FORMAT                30                      // 1 bit
#define CSDFT_DST_FORMAT                31                      // 1 bit

#define CSDFT_DIRECTION_MASK            0x1                     // bit 0
#define CSDFT_ORDER_MASK                0x2                     // bit 1
#define CSDFT_SRC_PRECISION_MASK        0xC                     // bit 2&3
#define CSDFT_SRC_TYPE_MASK             0x10                    // bit 4
#define CSDFT_DST_PRECISION_MASK        0x60                    // bit 5&6
#define CSDFT_DST_TYPE_MASK             0x80                    // bit 7

#define CSDFT_CONVOLVE_TRANSFORM_MASK   0x20000000              /* bit 29   */
#define CSDFT_SRC_FORMAT_MASK           0x40000000              // bit 30
#define CSDFT_DST_FORMAT_MASK           0x80000000UL            // bit 31

#define CSDFT_FORWARD                   (0 << CSDFT_DIRECTION)      // Default is FORWARD (0)
#define CSDFT_BACKWARD                  (1 << CSDFT_DIRECTION)      //                    (1)

#define CSDFT_NATURAL_ORDER             (0 << CSDFT_ORDER)          // Defaul is NATURAL
#define CSDFT_OPTIMAL_ORDER             (1 << CSDFT_ORDER)
//#define CSDFT_BIT_REVERSED_ORDER      (2 << CSDFT_ORDER)

#define CSDFT_SRC_BYTE                  (0 << CSDFT_SRC_PRECISION)  // Default is SINGLE
#define CSDFT_SRC_SHORT                 (1 << CSDFT_SRC_PRECISION)
#define CSDFT_SRC_SINGLE                (2 << CSDFT_SRC_PRECISION)
#define CSDFT_SRC_DOUBLE                (3 << CSDFT_SRC_PRECISION)

#define CSDFT_SRC_REAL                  (0 << CSDFT_SRC_TYPE)       // Default is COMPLEX
#define CSDFT_SRC_COMPLEX               (1 << CSDFT_SRC_TYPE)

#define CSDFT_DST_BYTE                  (0 << CSDFT_DST_PRECISION)  // Default is SINGLE
#define CSDFT_DST_SHORT                 (1 << CSDFT_DST_PRECISION)
#define CSDFT_DST_SINGLE                (2 << CSDFT_DST_PRECISION)
#define CSDFT_DST_DOUBLE                (3 << CSDFT_DST_PRECISION)

#define CSDFT_DST_REAL                  (0 << CSDFT_DST_TYPE)       // Default is COMPLEX
#define CSDFT_DST_COMPLEX               (1 << CSDFT_DST_TYPE)

#define CSDFT_SRC_INTERLEAVED           (0 << CSDFT_SRC_FORMAT)     // Default is INTERLEAVED
#define CSDFT_SRC_SPLIT_ARRAY           (1 << CSDFT_SRC_FORMAT)
#define CSDFT_DST_INTERLEAVED           (0 << CSDFT_DST_FORMAT)     // Default is INTERLEAVED
#define CSDFT_DST_SPLIT_ARRAY           (1 << CSDFT_DST_FORMAT)

// Combined source and destination
#define CSDFT_BYTE                      (CSDFT_SRC_BYTE|CSDFT_DST_BYTE)
#define CSDFT_SHORT                     (CSDFT_SRC_SHORT|CSDFT_DST_SHORT)
#define CSDFT_SINGLE                    (CSDFT_SRC_SINGLE|CSDFT_DST_SINGLE)
#define CSDFT_DOUBLE                    (CSDFT_SRC_DOUBLE|CSDFT_DST_DOUBLE)
#define CSDFT_REAL                      (CSDFT_SRC_REAL|CSDFT_DST_REAL)
#define CSDFT_COMPLEX                   (CSDFT_SRC_COMPLEX|CSDFT_DST_COMPLEX)
#define CSDFT_INTERLEAVED               (CSDFT_SRC_INTERLEAVED|CSDFT_DST_INTERLEAVED)
#define CSDFT_SPLIT_ARRAY               (CSDFT_SRC_SPLIT_ARRAY|CSDFT_DST_SPLIT_ARRAY)
#define CSDFT_TRANSFORM_KERNEL           CSDFT_CONVOLVE_TRANSFORM_MASK


typedef unsigned int CSDftFlags;


//============================================================================//
// enums and function prototypes for CSDft status routines                    //
//============================================================================//


enum _CSDftStatusTypes
{
    CSDFT_NO_ERROR,
    CSDFT_RUNNING,
    CSDFT_FINISHED,
    CSDFT_BOARD_ERROR,
    CSDFT_INVALID_BOARD,
    CSDFT_INVALID_PROCESSOR,
    CSDFT_MEMORY_ALLOCATION_ERROR,
    CSDFT_INVALID_MEMORY_DESCRIPTOR,
    CSDFT_INVALID_PLAN,
    CSDFT_INVALID_USER_FUNCTION,
    CSDFT_INVALID_SYMBOL,
    CSDFT_INVALID_SIZE,
    CSDFT_INVALID_FLAG,
    CSDFT_INVALID_PARAMETER
} ;

typedef enum _CSDftStatusTypes CSDftStatus ;

CSDftStatus CSDFT_get_status                () ;


//============================================================================//
// Function prototypes for CSDftPlan creation and execution routines          //
//============================================================================//


CSDftPlan CSDFT_create_plan_1d               (CSDftFlags    flags,
                                           unsigned int  size,
                                           unsigned int  number_of_ffts,
                                           double        scale);

CSDftPlan CSDFT_create_plan_2d               (CSDftFlags    flags,
                                           unsigned int  size_x,
                                           unsigned int  size_y,
                                           unsigned int  number_of_ffts,
                                           double        scale);
CSDftPlan CSDFT_create_plan_3d               (CSDftFlags    flags,
                                           unsigned int  size_x,
                                           unsigned int  size_y,
                                           unsigned int  size_z,
                                           unsigned int  number_of_ffts,
                                           double        scale);

CSDftPlan CSDFT_create_plan_1d_strided ( CSDftFlags   flags,
                                         unsigned int size,
                                         unsigned int num_ffts,
                                         double       scale,
                                         unsigned int fft_stride,
                                         unsigned int node_stride);

CSDftPlan CSDFT_create_convolution_plan_1d ( CSDftFlags   flags,
                                             unsigned int size,
                                             unsigned int number_of_ffts,
                                             double       scale
                                             ) ;

CSDftPlan CSDFT_create_convolution_plan_2d ( CSDftFlags   flags,
                                             unsigned int x_size,
                                             unsigned int y_size,
                                             unsigned int number_of_ffts,
                                             double       scale
                                             ) ;

CSDftStatus CSDFT_execute_convolution( const CSDftPlan       plan,
                                       CSDftMemoryDescriptor kernel,
                                       CSDftMemoryDescriptor source,
                                       CSDftMemoryDescriptor destination ) ;

CSDftStatus CSDFT_execute_dft      (const CSDftPlan handle,
                                    CSDftMemoryDescriptor src,
                                    CSDftMemoryDescriptor dst);

CSDftStatus CSDFT_free_plan                 (CSDftPlan plan);

CSDftMemoryDescriptor CSDFT_board_to_memory_descriptor
                                       ( void *       source_data,
                                         unsigned int size_in_bytes) ;

void *CSDFT_memory_descriptor_to_board( CSDftMemoryDescriptor handle ) ;

CSDftStatus           CSDFT_free        ( CSDftMemoryDescriptor handle ) ;

#define CSDFT_USER_SEM                   0x25

#endif
